@@ -243,6 +243,7 @@ Type wfield ncaas <foldername> to open on a specific folder.
 
         '''.format(remotepath,localdisk))
         tfetch = time.time()
+        from .io import parse_imager_mj2_folder
         dat,frames_avg, trialonsets,trialinfo = parse_imager_mj2_folder(remotepath, localdisk)
         del dat
         del frames_avg
@@ -295,6 +296,7 @@ Type wfield ncaas <foldername> to open on a specific folder.
 
         '''.format(remotepath,localdisk))
         tfetch = time.time()
+        from .io import parse_imager_mj2_folder
         dat,frames_avg, trialonsets,trialinfo = parse_imager_mj2_folder(remotepath, localdisk)
         del dat
         del frames_avg
@@ -456,7 +458,8 @@ def _motion(localdisk,
             mode = 'ecc',
             chunksize=256,
             outdisk = None,
-            in_place = False):
+            in_place = False,
+            plot_ext = '.pdf'):
     # TODO: check if a motion corrected file is already here
     # if a single binary file try in-place
     dat_path = glob(pjoin(localdisk,'*.bin'))
@@ -486,7 +489,7 @@ def _motion(localdisk,
     np.save(pjoin(outdisk,'motion_correction_shifts.npy'),shifts)
     np.save(pjoin(outdisk,'motion_correction_rotation.npy'),rshifts)
     from .plots import plot_summary_motion_correction
-    plot_summary_motion_correction(shifts,outdisk)
+    plot_summary_motion_correction(shifts,outdisk, plot_ext=plot_ext)
     del shifts
 
 def _baseline(localdisk, nbaseline_frames, nchannels = None):
@@ -534,7 +537,7 @@ def _decompose(localdisk, k, nchannels = None):
     np.save(pjoin(localdisk,'U.npy'),U)
     np.save(pjoin(localdisk,'SVT.npy'),SVT)
 
-def _hemocorrect(localdisk,fs,functional_channel = 0):
+def _hemocorrect(localdisk,fs,functional_channel = 0, plot_ext='.pdf'):
     U = np.load(pjoin(localdisk,'U.npy'))
     SVT = np.load(pjoin(localdisk,'SVT.npy'))
     
@@ -558,7 +561,8 @@ def _hemocorrect(localdisk,fs,functional_channel = 0):
                                           T,
                                           frame_rate=fs,
                                           duration = 12,
-                                          outputdir = localdisk)            
+                                          outputdir = localdisk,
+                                          plot_ext = plot_ext)
     
 def main():
     CLIParser()
